JBoss Tools SVN: r41872 - in trunk/openshift/docs/reference/en-US: images/Creating_an_OpenShift_Express_Application and 1 other directories.
by jbosstools-commits@lists.jboss.org
Author: irooskov(a)redhat.com
Date: 2012-06-11 20:09:48 -0400 (Mon, 11 Jun 2012)
New Revision: 41872
Modified:
trunk/openshift/docs/reference/en-US/Creating_an_OpenShift_Express_Application.xml
trunk/openshift/docs/reference/en-US/Viewing_the_remote_console.xml
trunk/openshift/docs/reference/en-US/images/Creating_an_OpenShift_Express_Application/application_creation_11.png
trunk/openshift/docs/reference/en-US/images/Creating_an_OpenShift_Express_Application/application_creation_12.png
trunk/openshift/docs/reference/en-US/images/OpenShift_Remote_Console/openshift_remote_console_01.png
trunk/openshift/docs/reference/en-US/images/OpenShift_Remote_Console/openshift_remote_console_02.png
Log:
updated based on new OpenShift interface
Modified: trunk/openshift/docs/reference/en-US/Creating_an_OpenShift_Express_Application.xml
===================================================================
--- trunk/openshift/docs/reference/en-US/Creating_an_OpenShift_Express_Application.xml 2012-06-11 22:04:44 UTC (rev 41871)
+++ trunk/openshift/docs/reference/en-US/Creating_an_OpenShift_Express_Application.xml 2012-06-12 00:09:48 UTC (rev 41872)
@@ -78,8 +78,11 @@
</mediaobject>
</figure>
<para>
- Now ready to create your OpenShift application, you will need to specify a name, the platform type to deploy for, from the <guilabel>Type</guilabel> drop-down list, and the <guilabel>Gear profile</guilabel> to be used. <!--Further gear profile information to go here-->
+ Now ready to create your OpenShift application, you will need to specify a name, the platform type to deploy for, from the <guilabel>Type</guilabel> drop-down list, and the <guilabel>Gear profile</guilabel> to be used.
</para>
+ <para>
+ The <guilabel>Gear profile</guilabel> option concerns the amount of physical space that will be allocated for use by the application. If you are running a trial version of OpenShift only the <guimenuitem>small</guimenuitem> <guilabel>Gear profile</guilabel> will be available to you.
+ </para>
<note>
<para>
No underscores or special characters are allowed in the application name.
Modified: trunk/openshift/docs/reference/en-US/Viewing_the_remote_console.xml
===================================================================
--- trunk/openshift/docs/reference/en-US/Viewing_the_remote_console.xml 2012-06-11 22:04:44 UTC (rev 41871)
+++ trunk/openshift/docs/reference/en-US/Viewing_the_remote_console.xml 2012-06-12 00:09:48 UTC (rev 41872)
@@ -8,7 +8,7 @@
</para>
</note>
<para>
- Similar to when you are running a server locally, you are also able to see console output for your remote OpenShift server. To have this output displayed to you, right-click on your OpenShift server in the <guilabel>Servers</guilabel> tab and select <menuchoice><guimenuitem>Show In</guimenuitem><guimenuitem>Remote console</guimenuitem></menuchoice>.
+ Similar to when you are running a server locally, you are also able to see console output for your remote OpenShift server. To have this output displayed to you, right-click on your OpenShift server in the <guilabel>Servers</guilabel> tab and select <menuchoice><guimenuitem>OpenShift</guimenuitem><guimenuitem>Tail files</guimenuitem></menuchoice>.
</para>
<figure id="openshift_remote_console_01">
<title>Selecting the OpenShift Profile</title>
Modified: trunk/openshift/docs/reference/en-US/images/Creating_an_OpenShift_Express_Application/application_creation_11.png
===================================================================
(Binary files differ)
Modified: trunk/openshift/docs/reference/en-US/images/Creating_an_OpenShift_Express_Application/application_creation_12.png
===================================================================
(Binary files differ)
Modified: trunk/openshift/docs/reference/en-US/images/OpenShift_Remote_Console/openshift_remote_console_01.png
===================================================================
(Binary files differ)
Modified: trunk/openshift/docs/reference/en-US/images/OpenShift_Remote_Console/openshift_remote_console_02.png
===================================================================
(Binary files differ)
13 years, 10 months
JBoss Tools SVN: r41871 - trunk/documentation/guides/JBDS_Release_Notes/en-US.
by jbosstools-commits@lists.jboss.org
Author: irooskov(a)redhat.com
Date: 2012-06-11 18:04:44 -0400 (Mon, 11 Jun 2012)
New Revision: 41871
Modified:
trunk/documentation/guides/JBDS_Release_Notes/en-US/Article_Info.xml
trunk/documentation/guides/JBDS_Release_Notes/en-US/Known_Issues.xml
Log:
updated with known issue
Modified: trunk/documentation/guides/JBDS_Release_Notes/en-US/Article_Info.xml
===================================================================
--- trunk/documentation/guides/JBDS_Release_Notes/en-US/Article_Info.xml 2012-06-11 21:44:41 UTC (rev 41870)
+++ trunk/documentation/guides/JBDS_Release_Notes/en-US/Article_Info.xml 2012-06-11 22:04:44 UTC (rev 41871)
@@ -8,7 +8,7 @@
<productname>JBoss Developer Studio</productname>
<productnumber>5.0</productnumber>
<edition>5.0.0</edition>
- <pubsnumber>7</pubsnumber>
+ <pubsnumber>8</pubsnumber>
<abstract>
<para>
These release notes contain important information related to the JBoss Developer Studio. New features, known issues, resources, and other current issues are addressed here.
Modified: trunk/documentation/guides/JBDS_Release_Notes/en-US/Known_Issues.xml
===================================================================
--- trunk/documentation/guides/JBDS_Release_Notes/en-US/Known_Issues.xml 2012-06-11 21:44:41 UTC (rev 41870)
+++ trunk/documentation/guides/JBDS_Release_Notes/en-US/Known_Issues.xml 2012-06-11 22:04:44 UTC (rev 41871)
@@ -3,23 +3,23 @@
<title>
Known Issues in version 5.0.0
</title>
- <para>
+<!-- <para>
There were no known issues at the time of release.
- </para>
-<!-- <para>
+ </para> -->
+ <para>
Following is a list of known issues at the time of release.
- </para> -->
- <!-- <variablelist> -->
- <!-- JBIDE-11635 -->
- <!-- <varlistentry>
+ </para>
+ <variablelist>
+ <!-- JBDS-2180 -->
+ <varlistentry>
<term>
- <ulink url="https://issues.jboss.org/jira/browse/JBIDE-11635">JBIDE-11635</ulink>
+ <ulink url="https://issues.jboss.org/jira/browse/JBDS-2180">JBDS-2180</ulink>
</term>
<listitem>
<para>
- When JAX-RS services are tested through JAX-RS Tooling and Web Service Tester integration, the URL of the service can include details about required parameters. If the included parameters require values to be specified, a dialog prompting for these values now appears to the user and validation of the values occurs if the service includes a Regular Expression. This new feature ensures all values are gathered and verified before testing the service, minimizing returned errors.
+ When installing JBoss Developer Studio 5 on Mac OS X, if you are running Java 7 you will only be able to install the 64bit version of JBoss Developer Studio. The current workaround o install the 32bit version is to use Java 6.
</para>
</listitem>
</varlistentry>
- </variablelist> -->
+ </variablelist>
</section>
13 years, 10 months
JBoss Tools SVN: r41867 - tags.
by jbosstools-commits@lists.jboss.org
Author: nickboldt
Date: 2012-06-11 17:11:39 -0400 (Mon, 11 Jun 2012)
New Revision: 41867
Added:
tags/jbosstools-3.3.0.CR1/
Log:
tag revision 41728 as 3.3.0.CR1
13 years, 10 months
JBoss Tools SVN: r41865 - trunk/download.jboss.org/jbosstools/updates/webtools/indigo.
by jbosstools-commits@lists.jboss.org
Author: nickboldt
Date: 2012-06-11 16:56:47 -0400 (Mon, 11 Jun 2012)
New Revision: 41865
Modified:
trunk/download.jboss.org/jbosstools/updates/webtools/indigo/index.html
Log:
release 3.3.0.CR1 to http://download.jboss.org/jbosstools/updates/webtools/indigo/
Modified: trunk/download.jboss.org/jbosstools/updates/webtools/indigo/index.html
===================================================================
--- trunk/download.jboss.org/jbosstools/updates/webtools/indigo/index.html 2012-06-11 20:56:28 UTC (rev 41864)
+++ trunk/download.jboss.org/jbosstools/updates/webtools/indigo/index.html 2012-06-11 20:56:47 UTC (rev 41865)
@@ -1,6 +1,6 @@
<html>
<head>
-<title>JBoss Tools - Web Tools - Development Milestone Update Site: 3.3.0.v20120504-1708-H74-Beta3.webtools</title>
+<title>JBoss Tools - Web Tools - Development Milestone Update Site: 3.3.0.v20120605-1519-H98-CR1webtools</title>
<style>
@import url("http://download.jboss.org/jbosstools/updates/web/site.css");
</style>
@@ -24,7 +24,7 @@
<h2 class="title">JBoss Tools - Web Tools - Development Milestone Update Site</h2>
<table width="100%">
<tr class="header">
- <td class="sub-header" width="100%"><span>Latest Build: 3.3.0.v20120504-1708-H74-Beta3.webtools</span></td>
+ <td class="sub-header" width="100%"><span>Latest Build: 3.3.0.v20120605-1519-H98-CR1webtools</span></td>
</tr>
<tr class="light-row" style="height: 30px">
@@ -81,20 +81,20 @@
</th>
</tr>
<tr style="background-color:
							#EEEEEE
						">
- <td class="rowLine"><a href="features/org.jboss.ide.eclipse.archives.feature_3.2.1.v20120504-0235-H64-Beta3.jar" style="font-size:x-small">org.jboss.ide.eclipse.archives.feature</a></td>
- <td><span style="font-size:x-small">3.2.1.v20120504-0235-H64-Beta3</span></td>
+ <td class="rowLine"><a href="features/org.jboss.ide.eclipse.archives.feature_3.2.1.v20120604-2017-H86-CR1.jar" style="font-size:x-small">org.jboss.ide.eclipse.archives.feature</a></td>
+ <td><span style="font-size:x-small">3.2.1.v20120604-2017-H86-CR1</span></td>
<td></td>
</tr>
<tr style="background-color:
							#FFFFFF
						">
- <td class="rowLine"><a href="features/org.jboss.ide.eclipse.as.feature_2.3.0.v20120504-2054-H105-Beta3.jar" style="font-size:x-small">org.jboss.ide.eclipse.as.feature</a></td>
- <td><span style="font-size:x-small">2.3.0.v20120504-2054-H105-Beta3</span></td>
+ <td class="rowLine"><a href="features/org.jboss.ide.eclipse.as.feature_2.3.0.v20120605-1904-H135-CR1.jar" style="font-size:x-small">org.jboss.ide.eclipse.as.feature</a></td>
+ <td><span style="font-size:x-small">2.3.0.v20120605-1904-H135-CR1</span></td>
<td><span style="font-size:x-small">
|
org.eclipse.wst.server.core.serverAdapter</span></td>
</tr>
<tr style="background-color:
							#EEEEEE
						">
- <td class="rowLine"><a href="features/org.jboss.tools.jmx.feature_1.2.0.v20120504-0232-H50-Beta3.jar" style="font-size:x-small">org.jboss.tools.jmx.feature</a></td>
- <td><span style="font-size:x-small">1.2.0.v20120504-0232-H50-Beta3</span></td>
+ <td class="rowLine"><a href="features/org.jboss.tools.jmx.feature_1.2.0.v20120604-2017-H70-CR1.jar" style="font-size:x-small">org.jboss.tools.jmx.feature</a></td>
+ <td><span style="font-size:x-small">1.2.0.v20120604-2017-H70-CR1</span></td>
<td></td>
</tr>
<tr style="background-color:#DDDDDD">
13 years, 10 months
JBoss Tools SVN: r41864 - in trunk/portlet/plugins/org.jboss.tools.portlet.core/src/org/jboss/tools/portlet/core: internal and 1 other directory.
by jbosstools-commits@lists.jboss.org
Author: snjeza
Date: 2012-06-11 16:56:28 -0400 (Mon, 11 Jun 2012)
New Revision: 41864
Modified:
trunk/portlet/plugins/org.jboss.tools.portlet.core/src/org/jboss/tools/portlet/core/IPortletConstants.java
trunk/portlet/plugins/org.jboss.tools.portlet.core/src/org/jboss/tools/portlet/core/internal/PortletRuntimeComponentProvider.java
trunk/portlet/plugins/org.jboss.tools.portlet.core/src/org/jboss/tools/portlet/core/internal/PortletRuntimeLibrariesContainerInitializer.java
Log:
JBIDE-12158 - portlet-api library not found for Gatein 3.3 and JBoss 7
Modified: trunk/portlet/plugins/org.jboss.tools.portlet.core/src/org/jboss/tools/portlet/core/IPortletConstants.java
===================================================================
--- trunk/portlet/plugins/org.jboss.tools.portlet.core/src/org/jboss/tools/portlet/core/IPortletConstants.java 2012-06-11 18:07:24 UTC (rev 41863)
+++ trunk/portlet/plugins/org.jboss.tools.portlet.core/src/org/jboss/tools/portlet/core/IPortletConstants.java 2012-06-11 20:56:28 UTC (rev 41864)
@@ -80,7 +80,11 @@
static final String SERVER_DEFAULT_DEPLOY_SIMPLE_PORTAL_SAR = "deploy/simple-portal.sar"; //$NON-NLS-1$
static final String SERVER_DEFAULT_DEPLOY_GATEIN = "deploy/gatein.ear"; //$NON-NLS-1$
+
+ static final String SERVER_DEFAULT_DEPLOY_GATEIN33 = "standalone/deployments/gatein.ear"; //$NON-NLS-1$
+ static final String GATEIN_MODULES_JAVAX_PORTLET_API_MAIN = "gatein/modules/javax/portlet/api/main"; //$NON-NLS-1$
+
static final String TOMCAT_LIB = "lib"; //$NON-NLS-1$
static final String JAR = ".jar"; //$NON-NLS-1$
Modified: trunk/portlet/plugins/org.jboss.tools.portlet.core/src/org/jboss/tools/portlet/core/internal/PortletRuntimeComponentProvider.java
===================================================================
--- trunk/portlet/plugins/org.jboss.tools.portlet.core/src/org/jboss/tools/portlet/core/internal/PortletRuntimeComponentProvider.java 2012-06-11 18:07:24 UTC (rev 41863)
+++ trunk/portlet/plugins/org.jboss.tools.portlet.core/src/org/jboss/tools/portlet/core/internal/PortletRuntimeComponentProvider.java 2012-06-11 20:56:28 UTC (rev 41864)
@@ -83,6 +83,10 @@
if (exists(configFile, IPortletConstants.SERVER_DEFAULT_DEPLOY_GATEIN)) {
return true;
}
+ // GateIn Portal Server 3.3 JBoss AS 7
+ if (exists(jbossLocation.toFile(), IPortletConstants.SERVER_DEFAULT_DEPLOY_GATEIN33)) {
+ return true;
+ }
return false;
}
// Tomcat portletcontainer
Modified: trunk/portlet/plugins/org.jboss.tools.portlet.core/src/org/jboss/tools/portlet/core/internal/PortletRuntimeLibrariesContainerInitializer.java
===================================================================
--- trunk/portlet/plugins/org.jboss.tools.portlet.core/src/org/jboss/tools/portlet/core/internal/PortletRuntimeLibrariesContainerInitializer.java 2012-06-11 18:07:24 UTC (rev 41863)
+++ trunk/portlet/plugins/org.jboss.tools.portlet.core/src/org/jboss/tools/portlet/core/internal/PortletRuntimeLibrariesContainerInitializer.java 2012-06-11 20:56:28 UTC (rev 41864)
@@ -166,7 +166,10 @@
if (libDirectory != null) {
libDirectory = new File(libDirectory, "lib"); //$NON-NLS-1$
} else {
+ libDirectory = getDirectory(jbossLocation.toFile(), IPortletConstants.GATEIN_MODULES_JAVAX_PORTLET_API_MAIN);
+ if (libDirectory == null) {
// Tomcat adds portlet-api.jar automatically
+ }
}
}
}
13 years, 10 months
JBoss Tools SVN: r41863 - trunk/download.jboss.org/jbosstools/builds/cascade.
by jbosstools-commits@lists.jboss.org
Author: nickboldt
Date: 2012-06-11 14:07:24 -0400 (Mon, 11 Jun 2012)
New Revision: 41863
Modified:
trunk/download.jboss.org/jbosstools/builds/cascade/swimlanes.txt
Log:
update swimlanes to reflect more dependencies on usage and that gwt depends on xulrunner now
Modified: trunk/download.jboss.org/jbosstools/builds/cascade/swimlanes.txt
===================================================================
--- trunk/download.jboss.org/jbosstools/builds/cascade/swimlanes.txt 2012-06-11 18:06:30 UTC (rev 41862)
+++ trunk/download.jboss.org/jbosstools/builds/cascade/swimlanes.txt 2012-06-11 18:07:24 UTC (rev 41863)
@@ -28,7 +28,7 @@
esb -> jst -> common -> tests
-gwt, runtime, tests, usage, drools, pi4soa, savara, teiid -> [NONE]
+runtime, tests, usage, drools, pi4soa, savara, teiid -> [NONE]
------------------------
@@ -50,6 +50,8 @@
maven -> examples
openshift -> as, jmx, archives, common, tests
birt -> hibernatetools
+xulrunner, gwt, freemarker -> usage
+gwt -> xulrunner
------------------------
13 years, 10 months
JBoss Tools SVN: r41862 - trunk/build/publish.
by jbosstools-commits@lists.jboss.org
Author: nickboldt
Date: 2012-06-11 14:06:30 -0400 (Mon, 11 Jun 2012)
New Revision: 41862
Modified:
trunk/build/publish/publish.sh
Log:
port changes from 33x to trunk re: pushd/popd, deprecated link to sources zip; JBDS-1992: add results page into installer/ folder
Modified: trunk/build/publish/publish.sh
===================================================================
--- trunk/build/publish/publish.sh 2012-06-11 15:09:34 UTC (rev 41861)
+++ trunk/build/publish/publish.sh 2012-06-11 18:06:30 UTC (rev 41862)
@@ -63,10 +63,9 @@
else
siteZip=${WORKSPACE}/sources/site/target/repository.zip
# JBIDE-10923
- currentDir=$(pwd)
- cd ${WORKSPACE}/sources/site/target/repository
+ pushd ${WORKSPACE}/sources/site/target/repository >/dev/null
zip -r $siteZip .
- cd $currentDir
+ popd >/dev/null
fi
z=$siteZip
fi
@@ -174,9 +173,10 @@
mkdir -p ${STAGINGDIR}/installer/
rsync -aq $z ${z}.MD5 ${STAGINGDIR}/installer/
# [fix for DEPRECATED PDE installer build] provide symlink so that the .product build can find the sources zip using a generic name, where SRCSNAME = ${JOB_NAME}-Sources-${ZIPSUFFIX}.zip
#mkdir -p ${STAGINGDIR}/all; cd ${STAGINGDIR}/all
#ln -s ../installer/${z} ${SRCSNAME}
#ln -s ../installer/${z}.MD5 ${SRCSNAME}.MD5
foundSourcesZip=1
done
if [[ $foundSourcesZip -eq 0 ]]; then
@@ -195,6 +195,12 @@
z=${STAGINGDIR}/all/${srczipname}; for m in $(md5sum ${z}); do if [[ $m != ${z} ]]; then echo $m > ${z}.MD5; fi; done
fi
+# JBDS-1992 create results page in installer/ folder, including update site zip, sources zip, and installers
+if [[ -d ${WORKSPACE}/sources/product/results/target ]]; then
+ mkdir -p ${STAGINGDIR}/installer/
+ rsync -aq ${WORKSPACE}/sources/product/results/target/* ${STAGINGDIR}/installer/
+fi
+
mkdir -p ${STAGINGDIR}/logs
# collect component zips from upstream aggregated build jobs
@@ -247,6 +253,7 @@
echo "" >> ${STAGINGDIR}/logs/${METAFILE}
# generate md5sums in a single file
+pushd ${STAGINGDIR} >/dev/null
md5sumsFile=${STAGINGDIR}/logs/md5sums.txt
echo "# Update Site Zips" > ${md5sumsFile}
echo "# ----------------" >> ${md5sumsFile}
@@ -256,6 +263,7 @@
echo "# -----------" >> ${md5sumsFile}
md5sum $(find . -iname "*source*.zip" | egrep -v "aggregate-Sources|nightly-Update") >> ${md5sumsFile}
echo " " >> ${md5sumsFile}
+popd >/dev/null
mkdir -p ${STAGINGDIR}/logs
13 years, 10 months
@@ -174,9 +173,10 @@
rsync -aq $z ${z}.MD5 ${STAGINGDIR}/installer/
# [fix for DEPRECATED PDE installer build] provide symlink so that the .product build can find the sources zip using a generic name, where SRCSNAME = ${JOB_NAME}-Sources-${ZIPSUFFIX}.zip
- #mkdir -p ${STAGINGDIR}/all; cd ${STAGINGDIR}/all
- #ln -s ../installer/${z} ${SRCSNAME}
- #ln -s ../installer/${z}.MD5 ${SRCSNAME}.MD5
+ #mkdir -p ${STAGINGDIR}/all; pushd ${STAGINGDIR}/all >/dev/null
+ #ln -s ../installer/${z##*/} ${SRCSNAME}
+ #ln -s ../installer/${z##*/}.MD5 ${SRCSNAME}.MD5
+ #popd >/dev/null
foundSourcesZip=1
done